import LabelText from 'atoms/LabelText';
import useDrupalTranslation from 'hooks/drupal_translation';
import CloudServiceProvider from 'model/CloudServiceProvider';
import AlertMessages from 'molecules/AlertMessages';
import Breadcrumbs from 'organisms/Breadcrumbs';
import LaunchTemplateTable from 'organisms/LaunchTemplateTable';
import PageTitle from 'organisms/PageTitle';
import SideBar from 'organisms/SideBar';
import { useContext, useState } from 'react';
import { Button, Col, Container, Form, Row } from 'react-bootstrap';
import { Link, useHistory, useParams } from 'react-router-dom';
import { AppContext } from 'service/state';

const CloudServerTemplatePage = () => {
  const params: {
    cloudServiceProvider: string,
    cloudContext?: string,
  } = useParams();
  const { t } = useDrupalTranslation();
  const { addMessage, addErrorMessage } = useContext(AppContext);
  const [isRefreshing, setRefreshing] = useState(false);
  const history = useHistory();

  const refresh = async () => {
    setRefreshing(true);
    const url = params.cloudContext !== undefined
      ? `/clouds/design/server_template/${params.cloudContext}/update`
      : `/clouds/design/${params.cloudServiceProvider}/server_template/update`;

    const response = await fetch(url, { method: 'POST' });
    setRefreshing(false);
    if (response.ok) {
      addMessage(t('Updated Server Template.'));
      history.push(
        params.cloudContext !== undefined
        ? `/${params.cloudServiceProvider}/${params.cloudContext}/server_template`
          : `/${params.cloudServiceProvider}/server_template`
      );
    } else {
      addErrorMessage(t('Unable to update Server Template.'));
    }
  }

  return <>
    <AlertMessages />
    <PageTitle designLabel='launch template' />
    <Breadcrumbs designLabel='Launch template' />
    <SideBar isOpenDesign/>
    <Container fluid className="px-0">
      <Row className="mx-0">
        <Col>
          <Form>
            <Form.Group style={{ marginBottom: '2rem' }}>
              {
                params.cloudContext
                ? <Link className="btn btn-primary" to={
                  `/${params.cloudServiceProvider}/${params.cloudContext}/server_template/create`
                }>
                  <LabelText text="Add launch template" />
                </Link>
                : <></>
              }
              <Button variant={isRefreshing ? 'secondary' : 'primary'}
                disabled={isRefreshing}
                onClick={refresh}>
                <LabelText text={
                  isRefreshing ? 'Refreshing...' : 'Refresh'
                } />
              </Button>
            </Form.Group>
            <LaunchTemplateTable cloudContext={{
              cloudServiceProvider: params.cloudServiceProvider as CloudServiceProvider,
              name: params.cloudContext === undefined ? 'ALL' : params.cloudContext,
              labelName: ''
            }} />
          </Form>
        </Col>
      </Row>
    </Container>
  </>;
}

export default CloudServerTemplatePage;
